@@ -34,6 +34,7 @@ from .literals import (
     ResourceTypeType,
     TypeType,
     ValidatePolicyFindingTypeType,
+    ValidatePolicyResourceTypeType,
 )
 
 if sys.version_info >= (3, 9):
@@ -1416,6 +1417,7 @@ _OptionalValidatePolicyRequestRequestTypeDef = TypedDict(
         "locale": LocaleType,
         "maxResults": int,
         "nextToken": str,
+        "validatePolicyResourceType": ValidatePolicyResourceTypeType,
     },
     total=False,
 )
